# PDFGet: Enter PDFGetEndpoint

Note: This document is currently under development. It will contain the following elements.

- description
- example

By default, the email address used in the git configuration is added to the unpaywall requests.

If you would like to use a different email address, use the following command

```
colrev settings --update-global=packages.pdf_get.colrev.unpaywall.email=<email_address>
```

## Links
